@@ -30,6 +30,7 @@ from PyQt4 import QtCore, QtGui
 
 from camelot.view.model_thread import model_function
 from camelot.core.backup import BackupMechanism
+from camelot.core.utils import ugettext_lazy as _
 from camelot.view import art
 from camelot.view import database_selection
 
@@ -107,7 +108,6 @@ methods :
     domain = 'python-camelot.com'
 
     version = '1.0'
-    sections = ['Relations', 'Configuration']
     admins = {}
 
     # This signal is emitted whenever the sections are changed, and the views
@@ -150,9 +150,12 @@ methods :
         
         .. image:: /_static/picture2.png
         """
-        from camelot.admin.section import structure_to_sections
-        return structure_to_sections(self.sections)
-
+        from camelot.admin.section import Section
+        
+        return [ Section( _('Relations'), self ),
+                 Section( _('Configuration'), self ),
+                 ]
+        
     def get_related_admin(self, cls):
         """Get the default :class:`camelot.admin.object_admin.ObjectAdmin` class
         for a specific class, return None, if not known.  The ObjectAdmin
@@ -200,16 +203,20 @@ methods :
         from camelot.view.mainwindow import MainWindow
         mainwindow = MainWindow(self)
         shortcut_versions = QtGui.QShortcut(
-            QtCore.Qt.CTRL+QtCore.Qt.ALT+QtCore.Qt.Key_V,
+            QtGui.QKeySequence( QtCore.Qt.CTRL+QtCore.Qt.ALT+QtCore.Qt.Key_V ),
             mainwindow
         )
         shortcut_versions.activated.connect( self.show_versions )
         shortcut_dump_state = QtGui.QShortcut(
-            QtCore.Qt.CTRL+QtCore.Qt.ALT+QtCore.Qt.Key_D,
+            QtGui.QKeySequence( QtCore.Qt.CTRL+QtCore.Qt.ALT+QtCore.Qt.Key_D ),
             mainwindow
         )
         shortcut_dump_state.activated.connect( self.dump_state )
-
+        shortcut_read_null = QtGui.QShortcut(
+            QtGui.QKeySequence( QtCore.Qt.CTRL+QtCore.Qt.ALT+QtCore.Qt.Key_0 ),
+            mainwindow
+        )
+        shortcut_read_null.activated.connect( self.read_null )
         return mainwindow
 
     @QtCore.pyqtSlot()
@@ -347,6 +354,9 @@ methods :
         if translations:
             _translations_data_.append( translations ) # keep the data alive
             translator = QtCore.QTranslator()
+            # PySide workaround for missing loadFromData method
+            if not hasattr( translator, 'loadFromData' ):
+                return
             if translator.loadFromData( translations ):
                 logger.info("add translation %s" % (directory + file_name))
                 return translator
@@ -431,6 +441,18 @@ methods :
                                               xlwt.__VERSION__,
                                               unicode(sys.path))
     
+    def read_null(self):
+        """Create a segmentation fault by reading null, this is to test
+        the faulthandling functions.  this method is triggered by pressing
+        :kbd:`Ctrl-Alt-0` in the GUI"""
+        ok = QtGui.QMessageBox.critical( None, 
+                                         'Experimental segfault',
+                                         'Are you sure you want to segfault the application',
+                                         buttons = QtGui.QMessageBox.No | QtGui.QMessageBox.Yes )
+        if ok == QtGui.QMessageBox.Yes:
+            import faulthandler
+            faulthandler._read_null()
+    
     def dump_state(self):
         """Dump the state of the application to the output, this method is
         triggered by pressing :kbd:`Ctrl-Alt-D` in the GUI"""
