@@ -313,13 +313,12 @@ be specified using the verbose_name attribute.
         """
         :return: a list of FormAction objects
         """
-        from camelot.admin.form_action import structure_to_form_actions
-        return structure_to_form_actions(self.form_actions)
+        from camelot.admin.action.form_action import structure_to_form_actions
+        return structure_to_form_actions( self.form_actions )
 
     @model_function
     def get_list_actions(self):
-        from camelot.admin.list_action import structure_to_list_actions
-        return structure_to_list_actions(self.list_actions)
+        return self.list_actions
 
     @model_function
     def get_depending_objects(self, obj):
