@@ -22,15 +22,32 @@
 #
 #  ============================================================================
 
-"""
-This is part of a test implementation of the new actions draft, it is not
-intended for production use
-"""
-
-from change_object import ChangeObject
+from change_object import ChangeObject, ChangeObjects
+from gui import OpenFormView, Refresh, ShowChart, ShowPixmap
+from open_file import OpenFile, OpenStream, OpenString, OpenJinjaTemplate
+from orm import CreateObject, DeleteObject, FlushSession, UpdateObject
+from print_preview import PrintHtml, PrintPreview, PrintJinjaTemplate
+from select_file import SelectFile
 from update_progress import UpdateProgress
 
 __all__ = [
     ChangeObject.__name__,
+    ChangeObjects.__name__,
+    CreateObject.__name__,
+    DeleteObject.__name__,
+    FlushSession.__name__,
+    OpenFile.__name__,
+    OpenFormView.__name__,
+    OpenJinjaTemplate.__name__,
+    OpenStream.__name__,
+    OpenString.__name__,
+    PrintHtml.__name__,
+    PrintJinjaTemplate.__name__,
+    PrintPreview.__name__,
+    Refresh.__name__,
+    SelectFile.__name__,
+    ShowChart.__name__,
+    ShowPixmap.__name__,
+    UpdateObject.__name__,
     UpdateProgress.__name__,
-    ]
\ No newline at end of file
+    ]
