@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -35,7 +35,7 @@ from PyQt4 import QtGui
 def file_(name):
     from camelot.core.resources import resource_filename
     import camelot
-    return resource_filename(camelot.__name__, 'art/%s'%name, 'CAMELOT_MAIN_DIRECTORY')
+    return resource_filename(camelot.__name__, 'art/%s'%name)
 
 
 def read(fname):
@@ -44,7 +44,6 @@ def read(fname):
     return resource_string(
         camelot.__name__,
         'art/%s' % fname,
-        'CAMELOT_MAIN_DIRECTORY'
     )
 
 
@@ -75,7 +74,7 @@ class Pixmap(object):
         from its package and copy it to a temp folder if the resource is
         packaged."""
         from camelot.core.resources import resource_filename
-        pth = resource_filename(self._module_name, 'art/%s'%(self._path), 'CAMELOT_MAIN_DIRECTORY')
+        pth = resource_filename(self._module_name, 'art/%s'%(self._path))
         if os.path.exists(pth):
             return pth
         else:
@@ -89,12 +88,15 @@ class Pixmap(object):
         from camelot.core.resources import resource_string
         from PyQt4.QtGui import QPixmap
         qpm = QPixmap()
-        success = qpm.loadFromData(resource_string(self._module_name,
-                                                   'art/%s'%(self._path),
-                                                   'CAMELOT_MAIN_DIRECTORY'))
-        if not success:
-            msg = u'Could not load pixmap %s from camelot art library'
-            logger.warn(msg % self._path)
+        p = os.path.join('art', self._path)
+        try:
+            # For some reason this throws a unicode error if the path contains an accent (cf windows username)
+            #  this happens only here, not for icons further on in the application
+            #  so they see no splash screen, tant pis
+            r = resource_string(self._module_name, p)
+            qpm.loadFromData(r)
+        except Exception, e:
+            logger.warn(u'Could not load pixmap "%s" from module: %s, encountered exception' % (p, self._module_name), exc_info=e)
         self._cached_pixmap = qpm
         return qpm
 
@@ -152,6 +154,7 @@ class ColorScheme(object):
     grey        = grey_0
 
     VALIDATION_ERROR = red_1
+    NOTIFICATION = yellow_1
     """
     for consistency with QT:
     Qt::white	3	 White (#ffffff)
@@ -176,3 +179,4 @@ class ColorScheme(object):
     Qt::color1	1	1 pixel value (for bitmaps)
     """
 
+
