@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -27,7 +27,6 @@ from PyQt4.QtCore import Qt
 from customdelegate import CustomDelegate, DocumentationMetaclass
 from camelot.view.controls import editors
 from camelot.core.utils import variant_to_pyobject
-from camelot.core import constants
 from camelot.view.proxy import ValueLoading
 
 class IntegerDelegate(CustomDelegate):
@@ -38,16 +37,13 @@ class IntegerDelegate(CustomDelegate):
     editor = editors.IntegerEditor
   
     def __init__(self,
-                 minimum=constants.camelot_minint,
-                 maximum=constants.camelot_maxint,
                  parent=None,
                  unicode_format = None,
                  **kwargs):
   
-        CustomDelegate.__init__(self, parent=parent, minimum=minimum, maximum=maximum, **kwargs)
-        self.minimum = minimum
-        self.maximum = maximum
+        CustomDelegate.__init__(self, parent=parent, **kwargs)
         self.unicode_format = unicode_format
+        self.locale = QtCore.QLocale()
         
     def paint(self, painter, option, index):
         painter.save()
@@ -57,13 +53,10 @@ class IntegerDelegate(CustomDelegate):
         if value in (None, ValueLoading):
             value_str = ''
         else:
-            value_str = QtCore.QString("%L1").arg( int(value) )
+            value_str = self.locale.toString( long(value) )
 
         if self.unicode_format is not None:
             value_str = self.unicode_format(value)
         
         self.paint_text( painter, option, index, value_str, horizontal_align=Qt.AlignRight )
         painter.restore()
-    
-
-
