@@ -51,6 +51,7 @@ class DateEditor(CustomEditor):
         self.setObjectName( field_name )
         self.date_format = local_date_format()
         self.line_edit = DecoratedLineEdit()
+        self.line_edit.set_minimum_width( len( self.date_format ) )
         self.line_edit.set_background_text( QtCore.QDate(2000,1,1).toString(self.date_format) )
 
         # The order of creation of this widgets and their parenting
@@ -111,8 +112,10 @@ class DateEditor(CustomEditor):
         self.editingFinished.emit()
 
     def focusOutEvent(self, event):
-        self.setProperty( 'value', QtCore.QVariant( self.get_value() ) )
-        self.valueChanged.emit()
+        # explicitely set value on focus out to format the date in case
+        # it was entered unformatted
+        value = self.get_value()
+        self.set_value( value )
         self.editingFinished.emit()
 
     def set_value(self, value):
