@@ -32,8 +32,7 @@ from PyQt4 import QtGui
 from PyQt4 import QtCore
 from PyQt4.QtCore import Qt
 
-#import sip
-
+from camelot.admin.action.form_action import FormActionGuiContext
 from camelot.view.art import Icon
 from camelot.view.model_thread import post
 from camelot.view.model_thread import model_function
@@ -59,6 +58,70 @@ class ContextMenuAction(QtGui.QAction):
         else:
             self.setIcon(self.default_icon.getQIcon())
 
+class FormEditors( object ):
+    """A class that holds the editors used on a form
+    """
+    
+    option = None
+    bold_font = None
+    
+    def __init__( self, columns, widget_mapper, delegate, admin ):
+        if self.option == None:
+            self.option = QtGui.QStyleOptionViewItem()
+            # set version to 5 to indicate the widget will appear on a
+            # a form view and not on a table view
+            self.option.version = 5
+            self.bold_font = QtGui.QApplication.font()
+            self.bold_font.setBold(True)
+            
+        self._admin = admin
+        self._widget_mapper = widget_mapper
+        self._field_attributes = dict()
+        self._index = dict()
+        for i, (field_name, field_attributes ) in enumerate( columns):
+            self._field_attributes[field_name] = field_attributes
+            self._index[field_name] = i
+        
+    def create_editor( self, field_name, parent ):
+        """
+        :return: a :class:`QtGuiQWidget` or None if field_name is unknown
+        """
+        index = self._index[field_name]
+        model = self._widget_mapper.model()
+        delegate = self._widget_mapper.itemDelegate()
+        model_index = model.index( self._widget_mapper.currentIndex(), index )
+        widget_editor = delegate.createEditor(
+            parent,
+            self.option,
+            model_index
+        )
+        widget_editor.setObjectName('%s_editor'%field_name)
+        delegate.setEditorData( widget_editor, model_index )
+        self._widget_mapper.addMapping( widget_editor, index )
+        return widget_editor
+    
+    def create_label( self, field_name, editor, parent ):
+        from camelot.view.controls.field_label import FieldLabel
+        from camelot.view.controls.editors.wideeditor import WideEditor
+        field_attributes = self._field_attributes[field_name]
+        hide_title = field_attributes.get( 'hide_title', False )
+        widget_label = None
+        if not hide_title:
+            widget_label = FieldLabel(
+                field_name,
+                field_attributes['name'],
+                field_attributes,
+                self._admin
+            )
+            widget_label.setObjectName('%s_label'%field_name)
+            if not isinstance(editor, WideEditor):
+                widget_label.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        # required fields font is bold
+        nullable = field_attributes.get( 'nullable', True )
+        if not nullable:
+            widget_label.setFont( self.bold_font )
+        return widget_label
+    
 class FormWidget(QtGui.QWidget):
     """A form widget comes inside a form view or inside an embedded manytoone editor"""
 
@@ -196,8 +259,6 @@ class FormWidget(QtGui.QWidget):
 
     def _create_widgets(self):
         """Create value and label widgets"""
-        from camelot.view.controls.field_label import FieldLabel
-        from camelot.view.controls.editors.wideeditor import WideEditor
         #
         # Dirty trick to make form views work during unit tests, since unit
         # tests have no event loop running, so the delegate will never be set,
@@ -212,65 +273,17 @@ class FormWidget(QtGui.QWidget):
         # only if all information is available, we can start building the form
         if not (self._form and self._columns and self._delegate):
             return
+        
         widgets = {}
         widget_mapper = self.findChild(QtGui.QDataWidgetMapper, 'widget_mapper' )
         if not widget_mapper:
             return
         LOGGER.debug( 'begin creating widgets' )
         widget_mapper.setItemDelegate(self._delegate)
-        option = QtGui.QStyleOptionViewItem()
-        # set version to 5 to indicate the widget will appear on a
-        # a form view and not on a table view
-        option.version = 5
-
-        bold_font = QtGui.QApplication.font()
-        bold_font.setBold(True)
-        #
-        # this loop can take a while to complete, so processEvents is called
-        # regulary
-        #
-        LOGGER.debug( 'begin creation loop' )
-        for i, (field_name, field_attributes ) in enumerate( self._columns):
-#            if i%10==0:
-#                QtCore.QCoreApplication.processEvents(
-#                    QtCore.QEventLoop.ExcludeSocketNotifiers,
-#                    100
-#                )
-            model_index = self._model.index(self._index, i)
-            hide_title = field_attributes.get( 'hide_title', False )
-            widget_label = None
-            widget_editor = self._delegate.createEditor(
-                self,
-                option,
-                model_index
-            )
-            widget_editor.setObjectName('%s_editor'%field_name)
-            if not hide_title:
-                widget_label = FieldLabel(
-                    field_name,
-                    field_attributes['name'],
-                    field_attributes,
-                    self._admin
-                )
-                widget_label.setObjectName('%s_label'%field_name)
-                if not isinstance(widget_editor, WideEditor):
-                    widget_label.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
-
-            # required fields font is bold
-            if ('nullable' in field_attributes) and \
-               (not field_attributes['nullable']):
-                widget_label.setFont(bold_font)
-
-            assert widget_editor != None
-            assert isinstance(widget_editor, QtGui.QWidget)
-
-            widget_mapper.addMapping(widget_editor, i)
-            widgets[field_name] = (widget_label, widget_editor)
-
-        LOGGER.debug( 'end creation loop' )
-        widget_mapper.setCurrentIndex(self._index)
+        widgets = FormEditors( self._columns, widget_mapper, self._delegate, self._admin )
+        widget_mapper.setCurrentIndex( self._index )
         LOGGER.debug( 'put widgets on form' )
-        self.layout().insertWidget(0, self._form.render(widgets, self))
+        self.layout().insertWidget(0, self._form.render( widgets, self, True) )
         LOGGER.debug( 'done' )
         #self._widget_layout.setContentsMargins(7, 7, 7, 7)
 
@@ -290,7 +303,7 @@ class FormView(AbstractView):
         layout = QtGui.QVBoxLayout()
         form_and_actions_layout = QtGui.QHBoxLayout()
         form_and_actions_layout.setObjectName('form_and_actions_layout')
-        layout.addLayout(form_and_actions_layout)
+        layout.addLayout( form_and_actions_layout )
 
         self.model = model
         self.admin = admin
@@ -367,17 +380,19 @@ class FormView(AbstractView):
         layout = self.findChild(QtGui.QLayout, 'form_and_actions_layout' )
         if actions and form and layout:
             side_panel_layout = QtGui.QVBoxLayout()
+            widget_mapper = self.findChild(QtGui.QDataWidgetMapper, 'widget_mapper' )
             from camelot.view.controls.actionsbox import ActionsBox
             LOGGER.debug('setting Actions for formview')
-            actions_widget = ActionsBox(self, self.model )
+            gui_context = FormActionGuiContext()
+            gui_context.workspace = self
+            gui_context.admin = self.admin
+            gui_context.widget_mapper = widget_mapper
+            actions_widget = ActionsBox( parent=self, gui_context=gui_context )
             actions_widget.setObjectName('actions')
-            action_widgets = actions_widget.setActions(actions)
-            for action_widget in action_widgets:
-                form.changed_signal.connect( action_widget.changed )
-                action_widget.changed( form.get_index() )
-            side_panel_layout.insertWidget(1, actions_widget)
+            actions_widget.set_actions( actions )
+            side_panel_layout.addWidget( actions_widget )
             side_panel_layout.addStretch()
-            layout.addLayout(side_panel_layout)
+            layout.addLayout( side_panel_layout )
 
     def viewFirst(self):
         """select model's first row"""
