@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -26,24 +26,31 @@ from PyQt4 import QtCore, QtGui
 
 from camelot.view.art import Icon
 from camelot.core.utils import ugettext as _
+from camelot.view.controls.abstract_widget import AbstractSearchWidget
 
-class SimpleSearchControl(QtGui.QWidget):
+class SimpleSearchControl(AbstractSearchWidget):
     """A control that displays a single text field in which search keywords can
-  be typed
+    be typed
 
-  emits a search and a cancel signal if the user starts or cancels the search
-  """
-
-    expand_search_options_signal = QtCore.pyqtSignal()
-    cancel_signal = QtCore.pyqtSignal()
-    search_signal = QtCore.pyqtSignal(str)
-    
+    emits a search and a cancel signal if the user starts or cancels the search
+    """
 
     def __init__(self, parent):
         QtGui.QWidget.__init__(self, parent)
         layout = QtGui.QHBoxLayout()
         layout.setSpacing(0)
-        layout.setMargin(3)
+        layout.setContentsMargins(3, 3, 3, 3)
+        
+        #
+        # The search timer reduced the number of search signals that are
+        # emitted, by waiting for the next keystroke before emitting the
+        # search signal
+        #
+        timer = QtCore.QTimer( self )
+        timer.setInterval( 300 )
+        timer.setSingleShot( True )
+        timer.setObjectName( 'timer' )
+        timer.timeout.connect( self.emit_search )
 
         # Search button
         self.search_button = QtGui.QToolButton()
@@ -58,10 +65,10 @@ class SimpleSearchControl(QtGui.QWidget):
         from camelot.view.controls.decorated_line_edit import DecoratedLineEdit
         self.search_input = DecoratedLineEdit(self)
         self.search_input.set_background_text(_('Search...'))
-        self.search_input.setToolTip(_('type words to search for'))
         #self.search_input.setStyleSheet('QLineEdit{ border-radius: 0.25em;}')
         self.search_input.returnPressed.connect( self.emit_search )
-        self.search_input.textEdited.connect( self.emit_search )
+        self.search_input.textEdited.connect( self._start_search_timer )
+        self.search_input.arrow_down_key_pressed.connect(self.on_arrow_down_key_pressed)
 
         self.setFocusProxy( self.search_input )
 
@@ -84,6 +91,14 @@ class SimpleSearchControl(QtGui.QWidget):
         self.search_input.setText(search_text)
         self.emit_search()
 
+    @QtCore.pyqtSlot()
+    @QtCore.pyqtSlot(str)
+    def _start_search_timer(self, str=''):
+        timer = self.findChild( QtCore.QTimer, 'timer' )
+        if timer:
+            timer.stop()
+            timer.start()
+        
     @QtCore.pyqtSlot()
     def emit_expand_search_options(self):
         self.expand_search_options_signal.emit()
@@ -91,11 +106,20 @@ class SimpleSearchControl(QtGui.QWidget):
     @QtCore.pyqtSlot()
     @QtCore.pyqtSlot(str)
     def emit_search(self, str=''):
+        timer = self.findChild( QtCore.QTimer, 'timer' )
+        if timer:
+            timer.stop()
         text = unicode(self.search_input.user_input())
         self.search_signal.emit( text )
 
     @QtCore.pyqtSlot()
     def emit_cancel(self):
+        timer = self.findChild( QtCore.QTimer, 'timer' )
+        if timer:
+            timer.stop()
         self.search_input.setText('')
         self.cancel_signal.emit()
 
+    @QtCore.pyqtSlot()
+    def on_arrow_down_key_pressed(self):
+        self.on_arrow_down_signal.emit()
