@@ -33,6 +33,8 @@ from PyQt4 import QtCore
 from PyQt4.QtCore import Qt
 from PyQt4.QtGui import QSizePolicy
 
+from camelot.admin.action.list_action import ListActionGuiContext
+from camelot.core.utils import ugettext as _
 from camelot.view.proxy.queryproxy import QueryTableProxy
 from camelot.view.controls.view import AbstractView
 from camelot.view.controls.user_translatable_label import UserTranslatableLabel
@@ -41,7 +43,6 @@ from camelot.view.model_thread import post
 from camelot.view.model_thread import gui_function
 from camelot.view.model_thread import model_function
 from camelot.view import register
-from camelot.core.utils import ugettext as _
 
 from search import SimpleSearchControl
 
@@ -184,7 +185,12 @@ and above the text.
     def _update_frozen_table(self):
         frozen_table_view = self.findChild(QtGui.QWidget, 'frozen_table_view' )
         if frozen_table_view:
-            frozen_table_view.setSelectionModel(self.selectionModel())
+            selection_model = self.selectionModel()
+            if selection_model != None: 
+                # explicitly check if there is a selection model, because
+                # setting the selection model to None will cause an assertion
+                # failure in Qt
+                frozen_table_view.setSelectionModel( selection_model )
             last_frozen =  min(self._columns_frozen, self.model().columnCount())
             frozen_width = 0
             for column in range(0, last_frozen):
@@ -368,13 +374,18 @@ class HeaderWidget( QtGui.QWidget ):
         """
         from camelot.view.controls.filter_operator import FilterOperator
         layout = QtGui.QHBoxLayout()
-        for field, attributes in columns:
+        layout.setSpacing( 2 )
+        for i, (field, attributes) in enumerate(columns):
             if 'operators' in attributes and attributes['operators']:
+                box = QtGui.QGroupBox()
+                box_layout = QtGui.QVBoxLayout()
                 widget = FilterOperator( self._admin.entity,
                                          field, attributes,
-                                         self )
+                                         box )
+                box_layout.addWidget( widget )
+                box.setLayout( box_layout )
                 widget.filter_changed_signal.connect( self._filter_changed )
-                layout.addWidget( widget )
+                layout.addWidget( box )
         layout.addStretch()
         self._expanded_search.setLayout( layout )
         self._expanded_filters_created = True
@@ -386,8 +397,11 @@ class HeaderWidget( QtGui.QWidget ):
         """Apply expanded filters on the query"""
         if self._expanded_filters_created:
             for i in range(self._expanded_search.layout().count()):
-                if self._expanded_search.layout().itemAt(i).widget():
-                    query = self._expanded_search.layout().itemAt(i).widget().decorate_query(query)
+                box = self._expanded_search.layout().itemAt(i).widget()
+                if box:
+                    widget = box.layout().itemAt(0).widget()
+                    if widget:
+                        query = widget.decorate_query(query)
         return query
 
     @QtCore.pyqtSlot()
@@ -548,7 +562,7 @@ class TableView( AbstractView  ):
     @QtCore.pyqtSlot(int)
     def sectionClicked( self, section ):
         """emits a row_selected signal"""
-        self.row_selected_signal.emit( section )
+        self.admin.list_action.gui_run( self.gui_context )
 
     def copy_selected_rows( self ):
         """Copy the selected rows in this tableview"""
@@ -594,6 +608,9 @@ class TableView( AbstractView  ):
         self.table.model().layoutChanged.connect( self.tableLayoutChanged )
         self.tableLayoutChanged()
         self.table_layout.insertWidget( 1, self.table )
+        self.gui_context = ListActionGuiContext()
+        self.gui_context.admin = self.admin
+        self.gui_context.item_view = self.table
 
         def get_filters_and_actions():
             return ( admin.get_filters(), admin.get_list_actions() )
@@ -602,7 +619,7 @@ class TableView( AbstractView  ):
 
     @QtCore.pyqtSlot()
     def on_keyboard_selection_signal(self):
-        self.table.verticalHeader().sectionClicked.emit(self.table.currentIndex().row())
+        self.sectionClicked( self.table.currentIndex().row() )
 
     @QtCore.pyqtSlot()
     @gui_function
@@ -792,17 +809,10 @@ class TableView( AbstractView  ):
         #
         self.rebuild_query()
         if actions:
-            #
-            # Attention, the ActionBox should only contain a reference to the
-            # table, and not to the table model, since this will cause the
-            # garbage collector to collect them both in random order, causing
-            # segfaults (see the test_qt_bindings)
-            #
-            actions_widget = ActionsBox( self,
-                                         self.get_collection_getter,
-                                         self.get_selection_getter )
+            actions_widget = ActionsBox( parent = self,
+                                         gui_context = self.gui_context )
             actions_widget.setObjectName( 'actions' )
-            actions_widget.setActions( actions )
+            actions_widget.set_actions( actions )
             self.filters_layout.addWidget( actions_widget )
 
     def to_html( self ):
