@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -28,9 +28,9 @@ from PyQt4 import QtGui
 from PyQt4 import QtCore
 
 from camelot.view.model_thread import post
-from camelot.view.model_thread import gui_function
 from camelot.view.model_thread import model_function
 
+
 class AbstractView(QtGui.QWidget):
     """A string used to format the title of the view ::
     title_format = 'Movie rental overview'
@@ -46,18 +46,23 @@ class AbstractView(QtGui.QWidget):
     header_widget = None
 
     title_changed_signal = QtCore.pyqtSignal(QtCore.QString)
+    icon_changed_signal = QtCore.pyqtSignal(QtGui.QIcon)
 
     @QtCore.pyqtSlot()
     def refresh(self):
         """Refresh the data in the current view"""
         pass
-    
-    @gui_function
+
+    @QtCore.pyqtSlot(object)
     def change_title(self, new_title):
         """Will emit the title_changed_signal"""
-        import sip
-        if not sip.isdeleted(self):
-            self.title_changed_signal.emit( unicode(new_title) )
+        #import sip
+        #if not sip.isdeleted(self):
+        self.title_changed_signal.emit( unicode(new_title) )
+        
+    @QtCore.pyqtSlot(object)
+    def change_icon(self, new_icon):
+        self.icon_changed_signal.emit(new_icon)
 
     @model_function
     def to_html(self):
@@ -98,6 +103,7 @@ class TabView(AbstractView):
             self.header = None
         layout.addWidget(self.header)
         self._tab_widget = QtGui.QTabWidget(self)
+        self._tab_widget.setObjectName( 'tab_widget' )
         layout.addWidget(self._tab_widget)
         self.setLayout(layout)
 
@@ -113,7 +119,7 @@ class TabView(AbstractView):
         for i in range(self._tab_widget.count()):
             view = self._tab_widget.widget(i)
             view.refresh()
-    
+
     def set_views_and_titles(self, views_and_titles):
         for view, title in views_and_titles:
             self._tab_widget.addTab(view, title)
@@ -130,3 +136,4 @@ class TabView(AbstractView):
     def to_html(self):
         return self._tab_widget.currentWidget().to_html()
 
+
