@@ -39,6 +39,7 @@ from PyQt4.QtCore import Qt, QThread
 from PyQt4 import QtGui, QtCore
 
 from camelot.core.utils import is_deleted
+from camelot.core.files.storage import StoredFile
 from camelot.view.art import Icon
 from camelot.view.fifo import Fifo
 from camelot.view.controls import delegates
@@ -660,7 +661,12 @@ position in the query.
             if new_value == ValueLoading:
                 return None
 
-            o = self._get_object( row )
+            #
+            # don't use _get_object, but only update objects which are in the
+            # cache, otherwise it is not sure that the object updated is the
+            # one that was edited
+            #
+            o = self.edit_cache.get_entity_at_row( row )
             if not o:
                 # the object might have been deleted from the collection while the editor
                 # was still open
@@ -727,9 +733,11 @@ position in the query.
                     #
                     if model_updated and hasattr(o, 'id') and o.id:
                         #
-                        # in case of images or relations, we cannot pickle them
+                        # in case of files or relations, we cannot pickle them
                         #
-                        if ( not 'Imag' in old_value.__class__.__name__ ) and not direction:
+                        if isinstance( old_value, StoredFile ):
+                            old_value = old_value.name
+                        if not direction:
                             from camelot.model.memento import BeforeUpdate
                             # only register the update when the camelot model is active
                             if hasattr(BeforeUpdate, 'query'):
@@ -886,7 +894,7 @@ position in the query.
                         break
                 limit = i - offset + 1
         except IndexError, e:
-            logger.warn('index error with rows_to_get %s'%unicode(rows_to_get), exc_info=e)
+            logger.error('index error with rows_to_get %s'%unicode(rows_to_get), exc_info=e)
             raise e
         return (offset, limit)
 
