@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -26,5 +26,6 @@ from camelot.core.resources import resource_filename
 
 import camelot.view
 
-loader = FileSystemLoader(resource_filename(camelot.view.__name__, 'templates', 'CAMELOT_MAIN_DIRECTORY'))
+loader = FileSystemLoader(resource_filename(camelot.view.__name__, 'templates'))
+
 
