@@ -1,5 +1,4 @@
 import logging
-import os
 
 FORMAT = '[%(levelname)-7s] [%(name)-35s] - %(message)s'
 logging.basicConfig(level=logging.INFO, format=FORMAT)
@@ -31,6 +30,8 @@ class ExampleSettings( SimpleSettings ):
         #
         from camelot_example.fixtures import load_movie_fixtures
         load_movie_fixtures()
+        from camelot.core.sql import update_database_from_model
+        #update_database_from_model()
         #
         # setup the views
         #
